<?php

declare(strict_types=1);

namespace Drupal\flex_processor\Component;

use Drupal\flex_processor\Exception\InvalidComponentKeyException;

/**
 * A value object that represents a data to be processed.
 *
 * @implements \IteratorAggregate<string, mixed>
 */
class DataComponent implements DataComponentInterface, \IteratorAggregate {

  /**
   * Component bundle.
   *
   * @var string
   */
  private string $bundle;

  /**
   * Data for the component.
   *
   * @var array<string, mixed>
   */
  private array $data;

  public function __construct(string $bundle, array $data) {
    $this->bundle = $bundle;
    $this->data = $data;
  }

  /**
   * {@inheritdoc}
   */
  public function bundle(): string {
    return $this->bundle;
  }

  /**
   * {@inheritdoc}
   */
  public function get(string $keyPath): mixed {

    $keys = explode('.', $keyPath);
    $value = $this->data;

    foreach ($keys as $key) {
      if (is_array($value) && array_key_exists($key, $value)) {
        $value = $value[$key];
      }
      else {
        // Throw custom exception if key path is invalid.
        throw new InvalidComponentKeyException("Key path '{$keyPath}' does not exist in the component data.");
      }
    }

    return $value;
  }

  /**
   * {@inheritdoc}
   */
  public function getIterator(): \Traversable {
    yield from $this->data;
  }

}
