<?php

namespace Drupal\flex_processor\Component;

/**
 * Interface DataComponentInterface.
 *
 * Defines the contract for a Component value object.
 */
interface DataComponentInterface {

  /**
   * Get the bundle of the component.
   *
   * @return string
   *   The component bundle.
   */
  public function bundle(): string;

  /**
   * Retrieve a value from the data using dot notation.
   *
   * @param string $keyPath
   *   The dot-notated key path (e.g., 'key1.subkey1').
   *
   * @return mixed
   *   The value found at the specified key path.
   *
   * @throws \Drupal\flex_processor\Exception\InvalidComponentKeyException
   *   If the key path does not exist.
   */
  public function get(string $keyPath): mixed;

}
