<?php

namespace Drupal\flex_processor\Event;

use Symfony\Contracts\EventDispatcher\Event;

/**
 * Event dispatched to get the proper processor ID for an unknown Data Source.
 */
class UnknownDataProcessorEvent extends Event {

  // This makes it easier for subscribers to reliably use our event name.
  const NAME = 'unknown_data_processor_event';

  const UNKNOWN_ID = 'unknown';

  /**
   * The unknown data source about to be processed.
   *
   * @var mixed
   */
  protected $dataSource;

  /**
   * Processor type for the data source.
   *
   * @var string
   */
  protected $type;

  /**
   * Processor bundle for the data source.
   *
   * @var string
   */
  protected $bundle;

  /**
   * Processor variant for the data source.
   *
   * @var string
   */
  protected $variant;

  public function __construct(mixed $dataSource, string $variant) {
    $this->dataSource = $dataSource;
    $this->type = self::UNKNOWN_ID;
    $this->bundle = self::UNKNOWN_ID;
    $this->variant = $variant;
  }

  /**
   * Get the data source.
   */
  public function getDataSource(): mixed {
    return $this->dataSource;
  }

  /**
   * Get the data source type.
   */
  public function getDataSourceType(): mixed {
    return $this->type;
  }

  /**
   * Get the data source bundle.
   */
  public function getDataSourceBundle(): mixed {
    return $this->bundle;
  }

  /**
   * Get the data source variant.
   */
  public function getDataSourceVariant(): mixed {
    return $this->variant;
  }

  /**
   * Sets the data source type.
   */
  public function setDataSourceType(string $type): mixed {
    return $this->type = $type;
  }

  /**
   * Sets the data source bundle.
   */
  public function setDataSourceBundle(string $bundle): mixed {
    return $this->bundle = $bundle;
  }

  /**
   * Sets the data source variant.
   */
  public function setDataSourceVariant(string $variant): mixed {
    return $this->variant = $variant;
  }

  /**
   * Gets component Type.
   *
   * @return array<string, string>
   *   The type identifying this component.
   */
  public function getDataSourceComponentType() : array {
    return [
      'type' => $this->getDataSourceType(),
      'bundle' => $this->getDataSourceBundle(),
      'variant' => $this->getDataSourceVariant(),
    ];
  }

}
