<?php

namespace Drupal\flex_processor\Plugin\FieldDataProcessors;

use Drupal\flex_processor\Plugin\FieldDataProcessor;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Returns the (structured) data of a field.
 *
 * @DataProcessor(
 *   id = "field_datetime",
 *   label = @Translation("Date time"),
 *   type = "field",
 *   bundles = {
 *     "datetime"
 *   }
 * )
 */
class FieldDateTime extends FieldDataProcessor {

  /**
   * The Date Formatter service.
   *
   * @var \Drupal\Core\Datetime\DateFormatterInterface
   */
  protected $dateFormatter;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    $instance = parent::create(
      $container,
      $configuration,
      $plugin_id,
      $plugin_definition,
    );

    $instance->dateFormatter = $container->get('date.formatter');

    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function process(mixed $field, array $options = []): mixed {

    $options += [
      'type' => 'medium',
      'format' => '',
      'timezone' => NULL,
      'langcode' => NULL,
    ];

    $timestamp = is_string($field->value) ? strtotime($field->value) : $field->value;
    return $this->dateFormatter->format($timestamp, $options['type'], $options['format'], $options['timezone'], $options['langcode']);
  }

}
