<?php

namespace Drupal\flex_processor\Plugin\FieldDataProcessors;

use Drupal\flex_processor\Plugin\FieldDataProcessor;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Returns the (structured) data of a field.
 *
 * @DataProcessor(
 *   id = "field_file",
 *   label = @Translation("File"),
 *   type = "field",
 *   bundles = {
 *     "file"
 *   }
 * )
 */
class FieldFile extends FieldDataProcessor {

  /**
   * Drupal\Core\File\FileUrlGenerator service.
   *
   * @var \Drupal\Core\File\FileUrlGenerator
   */
  protected $urlGenerator;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    $instance = parent::create(
      $container,
      $configuration,
      $plugin_id,
      $plugin_definition,
    );

    $instance->urlGenerator = $container->get('file_url_generator');

    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function process(mixed $field, array $options = []): mixed {
    return [
      'type' => 'file',
      'url' => $this->urlGenerator->generateAbsoluteString($field->entity->uri->value),
    ];
  }

}
