<?php

namespace Drupal\flex_processor\Plugin\FieldDataProcessors;

use Drupal\flex_processor\Plugin\FieldDataProcessor;
use Drupal\link\LinkItemInterface;

/**
 * Returns the (structured) data of a field.
 *
 * @DataProcessor(
 *   id = "field_link",
 *   label = @Translation("Link"),
 *   type = "field",
 *   bundles = {
 *     "link",
 *   }
 * )
 */
class FieldLink extends FieldDataProcessor {

  /**
   * {@inheritdoc}
   */
  public function process(mixed $field, array $options = []): mixed {
    $url = $this->buildUrl($field)->toString(TRUE);
    return [
      'label' => $field->title,
      'url' => $url->getGeneratedUrl(),
    ];

  }

  /**
   * Builds the \Drupal\Core\Url object for a link field item.
   *
   * @param \Drupal\link\LinkItemInterface $item
   *   The link field item being rendered.
   *
   * @return \Drupal\Core\Url
   *   A Url object.
   */
  protected function buildUrl(LinkItemInterface $item) {
    return $item->getUrl();
  }

}
